import ij.*;
import ij.plugin.*;
import ij.plugin.filter.*;
import ij.process.*;
import ij.gui.*;
import ij.measure.*;

/**	This plugin is an extended version of  ImageJ's Measure command that calculates
	the length and angle of a straight line selection or the length of a segmented
	line selection and the angle between the first two segments.
*/
public class Angle_ implements PlugIn {

	public void run(String arg) {
		if (IJ.versionLessThan("1.18o"))
			return;
		ImagePlus imp = WindowManager.getCurrentImage();
		if (imp==null)
			{IJ.noImage(); return;}
		Roi roi = imp.getRoi();
		if (roi==null || !(roi.getType()==Roi.LINE || roi.getType()==Roi.POLYLINE))
			{IJ.error("Straight or segmented line selection required"); return;}
		Analyzer a = new Analyzer();
		ImageStatistics stats = imp.getStatistics(Analyzer.getMeasurements());
		a.saveResults(stats, roi); // store in system results table
		ResultsTable rt =Analyzer.getResultsTable(); // get the system results table
		double angle = 0.0;
		if (roi.getType()==Roi.LINE) {
			Line line = (Line)roi;
			angle = roi.getAngle(line.x1, line.y1, line.x2, line.y2);
		} else if (roi.getType()==Roi.POLYLINE)
			angle = ((PolygonRoi)roi).getAngle();
		rt.addValue("Length", roi.getLength());
		rt.addValue("Angle", angle);
		a.displayResults(); //display the results in the worksheet
		a.updateHeadings(); // update the worksheet headings
	}

}

